@@ -3,13 +3,16 @@
 // [[Rcpp::depends(RcppArmadillo)]]
 
 // [[Rcpp::export]]
-arma::cube cmosaic_compose(Rcpp::StringVector file, arma::mat xy_pos, int xmax, int ymax){
+arma::cube cmosaic_compose(Rcpp::StringVector file, arma::mat xy_pos, int xmax, int ymax, int zmax){
   
   // define size of the final cube using data from the first
   std::string fname(file[0]);
   arma::cube A;
   A.load(fname, arma::arma_binary);
-  arma::cube out(A.n_rows * (xmax+1), A.n_cols * (ymax+1), A.n_slices);
+  if(zmax == -1){
+    zmax = A.n_slices;
+  }
+  arma::cube out(A.n_rows * (xmax+1), A.n_cols * (ymax+1), zmax);
   
   // get the fpa size
   int fpa = A.n_rows;
@@ -26,7 +29,7 @@ arma::cube cmosaic_compose(Rcpp::StringVector file, arma::mat xy_pos, int xmax,
     // we are using the .tube subview:
     int first_row = xy_pos(i, 0) * fpa;
     int first_col = xy_pos(i, 1) * fpa;
-    out.tube(first_row, first_col, first_row + fpa - 1, first_col + fpa - 1) = A;
+    out.tube(first_row, first_col, first_row + fpa - 1, first_col + fpa - 1) = A.slices(0, zmax-1);
   }
   
   return out;
